@@ -611,7 +611,7 @@ impl<'a> DBPoolConn<'a> {
         }
     }
 
-    pub async fn exec(&mut self, sql: &str) -> crate::Result<DBExecResult> {
+    pub async fn exec_sql(&mut self, sql: &str) -> crate::Result<DBExecResult> {
         self.check_alive()?;
         match self {
             #[cfg(feature = "mysql")]
@@ -800,21 +800,21 @@ impl<'a> DBTx<'a> {
             return Ok(());
         }
         let conn = self.get_conn_mut()?;
-        conn.exec("BEGIN").await?;
+        conn.exec_sql("BEGIN").await?;
         self.done = false;
         return Ok(());
     }
 
     pub async fn commit(&mut self) -> crate::Result<()> {
         let conn = self.get_conn_mut()?;
-        conn.exec("COMMIT").await?;
+        conn.exec_sql("COMMIT").await?;
         self.done = true;
         return Ok(());
     }
 
     pub async fn rollback(&mut self) -> crate::Result<()> {
         let conn = self.get_conn_mut()?;
-        conn.exec("ROLLBACK").await?;
+        conn.exec_sql("ROLLBACK").await?;
         self.done = true;
         return Ok(());
     }
@@ -835,9 +835,9 @@ impl<'a> DBTx<'a> {
         return conn.fetch_parperd(sql).await;
     }
 
-    pub async fn exec(&mut self, sql: &str) -> crate::Result<DBExecResult> {
+    pub async fn exec_sql(&mut self, sql: &str) -> crate::Result<DBExecResult> {
         let conn = self.get_conn_mut()?;
-        return conn.exec(sql).await;
+        return conn.exec_sql(sql).await;
     }
 
     pub async fn exec_prepare(&mut self, sql: DBQuery<'_>) -> crate::Result<DBExecResult> {
